Object.defineProperty(exports, "__esModule", { value: true });
const _ = require("lodash");
var rules;
(function (rules) {
    rules.SCOPED_COMMIT_REGEXP = /[a-z]+[\s]?\(.+\):/;
    function bannedPhrases(text, part, bannedPhrases) {
        return {
            failed: new RegExp(`(${bannedPhrases.join("|")})`, "ig").test(text),
            message: `Commit '${part}' is not valid. You are using a 'Banned Phrase'. Banned phrases are: ${bannedPhrases.join(", ")}.`
        };
    }
    rules.bannedPhrases = bannedPhrases;
    function noUnscoped(text) {
        return {
            failed: !rules.SCOPED_COMMIT_REGEXP.test(text),
            message: "Unscoped commit messages are not allowed."
        };
    }
    rules.noUnscoped = noUnscoped;
    function maxLength(text, part, maxLength) {
        return {
            failed: maxLength < text.length,
            message: `Commit '${part}' cannot exceed ${maxLength} characters.`
        };
    }
    rules.maxLength = maxLength;
    function validScopes(text, part, validScopes) {
        return {
            failed: !new RegExp(`^(${validScopes.join("|")})$`).test(text),
            message: `Commit '${part}' is not valid. Valid scopes are: ${validScopes.join(", ")}.`
        };
    }
    rules.validScopes = validScopes;
    function validTypes(text, part, validTypes) {
        return {
            failed: !new RegExp(`^(${validTypes.join("|")})$`).test(text),
            message: `Commit '${part}' is not valid. Valid types are: ${validTypes.join(", ")}.`
        };
    }
    rules.validTypes = validTypes;
    function noDash(text, part) {
        return {
            failed: text.indexOf("-") > -1,
            message: `Commit '${part}' cannot contain dashes.`
        };
    }
    rules.noDash = noDash;
    function noSpace(text, part) {
        return {
            failed: text.indexOf(" ") > -1,
            message: `Commit '${part}' cannot contain spaces.`
        };
    }
    rules.noSpace = noSpace;
    function noUnderscore(text, part) {
        return {
            failed: text.indexOf("_") > -1,
            message: `Commit '${part}' cannot contain underscore.`
        };
    }
    rules.noUnderscore = noUnderscore;
    function noCamelCase(text, part) {
        return {
            failed: _.camelCase(text) === text,
            message: `Commit '${part}' cannot be in CamelCase format.`
        };
    }
    rules.noCamelCase = noCamelCase;
    function noKebabCase(text, part) {
        return {
            failed: _.kebabCase(text) === text,
            message: `Commit '${part}' cannot be in KebabCase format.`
        };
    }
    rules.noKebabCase = noKebabCase;
    function noUpperFirst(text, part) {
        return {
            failed: /^[A-Z]/.test(text),
            message: `Commit '${part}' first character cannot be UpperCase.`
        };
    }
    rules.noUpperFirst = noUpperFirst;
    function noLowerFirst(text, part) {
        return {
            failed: /^[a-z]/.test(text),
            message: `Commit '${part}' first character cannot be in LowerCase.`
        };
    }
    rules.noLowerFirst = noLowerFirst;
    function noPeriodAtEnd(text, part) {
        return {
            failed: /[.]$/.test(text),
            message: `Commit '${part}' last character cannot be a period.`
        };
    }
    rules.noPeriodAtEnd = noPeriodAtEnd;
})(rules = exports.rules || (exports.rules = {}));
